@@ -2,16 +2,17 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
+
 from . import account
 
 
 def register():
     Pool.register(
-        account.TaxTemplate,
-        account.TaxRuleTemplate,
+        account.AccountTemplate,
         account.FrFECStart,
         account.FrFECResult,
         module='account_fr', type_='model')
     Pool.register(
+        account.CreateChart,
         account.FrFEC,
         module='account_fr', type_='wizard')
